@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,12 +26,33 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2008 ImageMagick Studio LLC"
-#define MagickLibVersion  0x645
-#define MagickLibVersionText  "6.4.5"
-#define MagickLibVersionNumber  1,0,0
-#define MagickReleaseDate  "2010-03-21"
-#define MagickChangeDate   "20081114"
+#define MagickCopyright  "Copyright (C) 1999-2011 ImageMagick Studio LLC"
+#define MagickLibVersion  0x666
+#define MagickLibVersionText  "6.6.6"
+#define MagickLibVersionNumber  4,0,1
+#define MagickLibAddendum  "-10"
+#define MagickLibInterface  4
+#define MagickLibMinInterface  4
+#define MagickReleaseDate  "2011-08-04"
+#define MagickChangeDate   "20100101"
+#define MagickAuthoritativeURL  "http://www.imagemagick.org"
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
+#define MagickOpenMPFeature  "OpenMP "
+#else
+#define MagickOpenMPFeature  " "
+#endif
+#if defined(MAGICKCORE_OPENCL_SUPPORT)
+#define MagickOpenCLFeature  "OpenCL "
+#else
+#define MagickOpenCLFeature  " "
+#endif
+#if defined(MAGICKCORE_HDRI_SUPPORT)
+#define MagickHDRIFeature  "HDRI "
+#else
+#define MagickHDRIFeature  " "
+#endif
+#define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature
+#define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
@@ -48,32 +69,21 @@ extern "C" {
 #define MagickQuantumDepth  "Q?"
 #define MagickQuantumRange  "?"
 #endif
-#if !defined(MAGICKCORE_HDRI_SUPPORT)
-#define MagickHDRISupport ""
-#else
-#define MagickHDRISupport "HDRI "
-#endif
-#if !defined(_OPENMP)
-#define MagickOPENMPSupport ""
-#else
-#define MagickOPENMPSupport "OpenMP "
-#endif
-#define MagickSupport MagickHDRISupport MagickOPENMPSupport
-#define MagickVersion MagickPackageName " " MagickLibVersionText " " \
-  MagickReleaseDate " " MagickQuantumDepth " " MagickSupport \
-  "http://www.imagemagick.org"
-#define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
+#define MagickVersion  \
+  MagickPackageName " " MagickLibVersionText MagickLibAddendum " " \
+  MagickReleaseDate " " MagickQuantumDepth " " MagickAuthoritativeURL
 
 extern MagickExport char
   *GetMagickHomeURL(void);
 
 extern MagickExport const char
   *GetMagickCopyright(void),
+  *GetMagickFeatures(void),
   *GetMagickPackageName(void),
-  *GetMagickQuantumDepth(unsigned long *),
-  *GetMagickQuantumRange(unsigned long *),
+  *GetMagickQuantumDepth(size_t *),
+  *GetMagickQuantumRange(size_t *),
   *GetMagickReleaseDate(void),
-  *GetMagickVersion(unsigned long *);
+  *GetMagickVersion(size_t *);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
